Schemas
*******

Could have different schema for different purposes, e.g. a valid WMS schema. 
Nested schemas are in the Draft 4 spec only - https://spacetelescope.github.io/understanding-json-schema/structuring.html

.. include:: schemas/map.rst

.. include:: schemas/layer.rst

..
    For docs: https://github.com/inspirehep/jsonschema2rst